# Prowl

> [!WARNING]
> Currently in early-stage development.

Library to generate [caracal](https://github.com/dioptra-io/caracal) / [caracat](https://github.com/maxmouchet/caracat) probes. Also intended to be used with [saimiris](https://github.com/nxthdr/saimiris).

## Installation

First create a virtual environment with [poetry](https://python-poetry.org/).

```bash
poetry shell
```

Then install Prowl.

```bash
poetry install
```

## Examples

You can find examples in the `examples` directory.

```bash
python examples/ping.py
python examples/traceroute.py
```
